@@ -4,7 +4,7 @@ use strict;
 use AnyEvent::HTTP;
 use HTTP::Request::Common 'POST';
 use base 'Exporter';
-our $VERSION = '0.021';
+our $VERSION = '0.2';
 
 our @EXPORT = qw(image_host);
 
@@ -12,6 +12,7 @@ sub image_host {
 	my $file = shift;
 	my $cb   = pop;
 	my $url = '';
+	
 	if ($file =~ /^http:\/\//) {
 		$url  = $file;
 		$file = undef;
@@ -22,44 +23,31 @@ sub image_host {
 	$AnyEvent::HTTP::MAX_PER_HOST ||= $opt->{'max_per_host'};
 	$AnyEvent::HTTP::ACTIVE       ||= $opt->{'active'      };
 	
-	
 	my $p = POST
-		'http://post.imageshack.us/',
-		Content_Type => 'multipart/form-data; boundary=---------------------------2561254751908746572894418409',
-		Referer      => 'http://imageshack.us',
-		Host         => 'post.imageshack.us',
-		Accept       => 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
-		DNT          => 1,
+		'http://www.imageshack.us/upload_api.php',
+		Content_Type => 'multipart/form-data',
 		Content      => [
-			uploadtype    => 'on',
 			fileupload    => $file ? [ $file ] : [ '' ],
 			url           => $url,
-			email         => '',
-			MAX_FILE_SIZE => 13145728,
-			refer         => '',
-			brand         => '',
-			optimage      => 'resample',
-			optsize       => 'resample',
-			rembar        => 0,
+			tags          => $opt->{'tags'} || '',
+			rembar        => $opt->{'remove_size'} || 1,
+			optimage      => 1,
+			key           => $opt->{'key'},
+			optsize       => $opt->{'size'} || 'resample',
 		]
 	;
 	
 	http_post 
 		$p->uri,
-		(join '', map {
-			s{name="fileupload"}{name="fileupload"; filename=""
-Content-Type: application/octet-stream} if $url;
-			$_;
-		} $p->content),
+		$p->content,
 		recurse => 0,
 		headers => {
 			map {
 				$_ => $p->header($_)
 			} $p->header_field_names
-			
 		},
 		sub {
-			$cb->(map { s{.+&l=(\w*)/(.+)$}{http://$1.imageshack.us/$1/$2}; $_ } $_[1]->{'location'});
+			$cb->($_[0] =~ /image_link>([^<>]+)</si);
 		}
 	;
 }
@@ -71,14 +59,14 @@ AnyEvent::ImageShack - simple non-blocking client for image hosting ImageShack.u
 
 =head1 VERSION
 
-0.021
+0.2
 
 =head1 SYNOPSIS
 
    use AnyEvent::ImageShack;
    
    my $c = AnyEvent->condvar;
-   image_host('url/or/path/to/image.png', sub { warn shift; $c->send });
+   image_host('url/or/path/to/image.png', key => 'developer_key123', sub { warn shift; $c->send });
    $c->recv;
 
 =head1 METHODS
@@ -101,6 +89,16 @@ Host image C<$image> to ImageShack.us
 
 =item max_per_host - maximum connections per one host for L<AnyEvent::HTTP>
 
+=item key - developer key for ImageShack API
+
+=item tags - tags for hosted image
+
+=item remove_size - remove information about size from thumbnails (by default 1)
+
+=item size - resize image to specified resolution (by default don't resize)
+
+=item 
+
 =back
 
 =head1 SUPPORT
@@ -111,6 +109,10 @@ Host image C<$image> to ImageShack.us
 
 L<http://github.com/konstantinov/AnyEvent-ImageShack>
 
+=item * ImageShack API
+
+L<http://code.google.com/p/imageshackapi/>
+
 =back
 
 =head1 SEE ALSO
@@ -119,6 +121,6 @@ L<AnyEvent>, L<AnyEvent::HTTP>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010-2011 Dmitry Konstantinov. All right reserved.
+Copyright 2010-2012 Dmitry Konstantinov. All right reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
